@@ -12,11 +12,11 @@ XML::RPC::Fast - Fast and modular implementation for an XML-RPC client and serve
 
 =head1 VERSION
 
-Version 0.5
+Version 0.6
 
 =cut
 
-our $VERSION   = '0.5';
+our $VERSION   = '0.6';
 
 =head1 SYNOPSIS
 
@@ -388,7 +388,7 @@ sub req {
 		$body = $self->encoder->request( $methodname, @params );
 	}
 
-	#$self->{xml_out} = $body;
+	$self->{xml_out} = $body;
 
 	#my $start = time;
 	my @data;
